@@ -144,7 +144,7 @@ class TorchFitter:
             with torch.no_grad():  # no gradient update
                 batch_size = images.shape[0]
                 images = images.to(self.device).float()
-                labels = labels.to(self.device).float()
+                labels = labels.to(self.device)
 
                 # just forward propagation
                 output = self.model(images)
@@ -176,7 +176,7 @@ class TorchFitter:
             # extract images and labels from the dataloader
             batch_size = images.shape[0]
             images = images.to(self.device).float()
-            labels = labels.to(self.device).float()
+            labels = labels.to(self.device)
 
             self.optimizer.zero_grad()
 
